| elfchange | R Documentation |
Calculates and plots percent richness change resulting from streamflow reductions
elfchange(stats, yaxis_thresh, xlabel = FALSE, ylabel = FALSE)
stats |
A dataframe of ELF statistics |
yaxis_thresh |
Value used for specifying y-axis max limit |
xlabel |
Used to overwrite default x-axis label |
ylabel |
Used to overwrite default y-axis label |
Plot of percent decreases in richness from flow reductions
#elfdata(watershed.code = '0208020104', ichthy.localpath = tempdir(), use_cache = FALSE)
breakpt <- 500
elf <- elfgen(
"watershed.df" = watershed.df,
"quantile" = 0.95,
"breakpt" = breakpt,
"xlabel" = "Mean Annual Flow (ft3/s)",
"ylabel" = "Fish Species Richness"
)
elfchange(elf$stats, "yaxis_thresh" = 25)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.